SystemOrganization addCategory: #ConfigurationOfMagritte!

Object subclass: #ConfigurationOfMagritte
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMagritte'!

!ConfigurationOfMagritte class methodsFor: 'private' stamp: 'EstebanLorenzano 12/18/2009 15:29'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMagritte class methodsFor: 'private' stamp: 'DaleHenrichs 1/6/2010 16:48'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfMagritte class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 12/18/2009 15:29'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfMagritte class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 12/18/2009 15:29'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMagritte class methodsFor: 'loading' stamp: 'DaleHenrichs 12/19/2009 14:11'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfMagritte class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 12/18/2009 15:29'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMagritte class methodsFor: 'accessing' stamp: 'EstebanLorenzano 12/18/2009 15:29'!
project

	^self new project! !

!ConfigurationOfMagritte methodsFor: 'baselines' stamp: 'DaleHenrichs 1/18/2010 14:35'!
baseline1000: spec
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://source.lukas-renggli.ch/magritte'. 
		spec
			project: 'Seaside2.8a1' with: [
				spec
					className: 'ConfigurationOfSeaside28';
					versionString: '2.8.4-baseline';
					file: 'ConfigurationOfSeaside28';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec 
			package: 'Magritte-Model';
			package: 'Magritte-Seaside' with: [
				spec requires: #('Magritte-Model' 'Seaside2.8a1')];
			package: 'Magritte-Tests' with: [
				spec requires: #('Magritte-Model' )]].
	spec for: #squeakCommon do: [
		spec 
			package: 'Magritte-Morph' with: [
				spec requires: #('Magritte-Model' )];
			yourself. ].
	spec for: #gemstone do: [
		spec repository: 'http://source.lukas-renggli.ch/magritte'.
		spec
			project: 'Change-Notification' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					loads: #('Change-Notification');
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			project: 'Core' with: [
				spec
					className: 'ConfigurationOfGsCore';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/GLASSproject' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					file: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/GemStone' ];
			yourself.
		spec 
			package: 'Magritte-Model' with: [ spec requires: #('Core' 'Change-Notification' 'OB' ) ];
			yourself.
		spec
			group: 'default' with: #('Magritte-Model' 'Magritte-Tests');
			yourself. ].! !

!ConfigurationOfMagritte methodsFor: 'baselines' stamp: 'DaleHenrichs 1/18/2010 14:35'!
baseline1211: spec
	<version: '1.2.1.1-baseline' imports: #('1.0-baseline' )>
	
	spec for: #common do: [
		spec blessing: #baseline].
	spec for: #squeakCommon do: [
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Magritte-Model' 'Magritte-Morph');
			group: 'Tests' with: #('Magritte-Tests')
			yourself].
! !

!ConfigurationOfMagritte methodsFor: 'doits' stamp: 'DaleHenrichs 12/19/2009 14:04'!
postLoad290Gs

	Smalltalk at: #MADescriptionBuilder ifPresent: [:cl |  cl default: nil ]! !

!ConfigurationOfMagritte methodsFor: 'accessing' stamp: 'EstebanLorenzano 12/18/2009 15:29'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear ]! !

!ConfigurationOfMagritte methodsFor: 'versions' stamp: 'DaleHenrichs 12/20/2009 13:50'!
version1200: spec
	<version: '1.2' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec project: 'Seaside2.8a1' with: '2.8.4.2'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Magritte-Model' with: 'Magritte-Model-lr.352';
			package: 'Magritte-Morph' with: 'Magritte-Morph-tg.46';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-lr.303';
			package: 'Magritte-Tests' with: 'Magritte-Tests-lr.153' ].
	spec for: #gemstone do: [
		spec
			project: 'Core' with: '0.232.4';
			project: 'Change-Notification' with: '0.232.4';
			project: 'OB' with: '0.232.4'.
		spec 
			package: 'Magritte-Model' with: [
				spec
					file:'Magritte-Model-dkh.354';
					postLoadDoIt: #postLoad290Gs.];
			package: 'Magritte-Tests' with: 'Magritte-Tests-dkh.158';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-dkh.305'.].
! !

!ConfigurationOfMagritte methodsFor: 'versions' stamp: 'DaleHenrichs 12/20/2009 13:57'!
version1210: spec
	<version: '1.2.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: '- fixed two recently reported bugs:
  1. MAExternalFileModel should override the equals method (Jan van de Sandt)
  2. MAValidation uses reusumeable exceptions and is messy too (Udo Schneider)
- normalize broken file-names before serializing them
'.
		spec project: 'Seaside2.8a1' with: '2.8.4.2'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Magritte-Model' with: 'Magritte-Model-lr.365';
			package: 'Magritte-Morph' with: 'Magritte-Morph-tg.46';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-lr.313';
			package: 'Magritte-Tests' with: 'Magritte-Tests-lr.159' ].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec description: 'Magritte 1.2.1 not yet ported to GemStone'.
		spec
			project: 'Core' with: '0.232.4';
			project: 'Change-Notification' with: '0.232.4';
			project: 'OB' with: '0.232.4'.
		spec 
			package: 'Magritte-Model' with: [
				spec
					file:'Magritte-Model-dkh.354';
					postLoadDoIt: #postLoad290Gs.];
			package: 'Magritte-Tests' with: 'Magritte-Tests-dkh.158';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-dkh.305'.].

	! !

!ConfigurationOfMagritte methodsFor: 'versions' stamp: 'DaleHenrichs 1/27/2010 16:52'!
version1211: spec
	<version: '1.2.1.1' imports: #('1.2.1.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: '- define groups
'.
		spec project: 'Seaside2.8a1' with: '2.8.4.2'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Magritte-Model' with: 'Magritte-Model-lr.365';
			package: 'Magritte-Morph' with: 'Magritte-Morph-tg.46';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-lr.313';
			package: 'Magritte-Tests' with: 'Magritte-Tests-lr.159' ].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec description: 'Magritte 1.2.1 not yet ported to GemStone'.
		spec
			project: 'Core' with: '0.232.4';
			project: 'Change-Notification' with: '0.232.4';
			project: 'OB' with: '0.232.4'.
		spec 
			package: 'Magritte-Model' with: [
				spec
					file:'Magritte-Model-dkh.354';
					postLoadDoIt: #postLoad290Gs.];
			package: 'Magritte-Tests' with: 'Magritte-Tests-dkh.158';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-dkh.305'.].

	! !

!ConfigurationOfMagritte methodsFor: 'versions' stamp: 'DaleHenrichs 1/27/2010 17:11'!
version1212: spec
	<version: '1.2.1.2' imports: #('1.2.1.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: '- pick up latest versions (1/27/2010 16:52
'.
		spec project: 'Seaside2.8a1' with: '2.8.4.2'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Magritte-Model' with: 'Magritte-Model-TestRunner.366';
			package: 'Magritte-Morph' with: 'Magritte-Morph-tg.46';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-lr.314';
			package: 'Magritte-Tests' with: 'Magritte-Tests-lr.159' ].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec description: 'Magritte 1.2.1 not yet ported to GemStone'.
		spec
			project: 'Core' with: '0.232.4';
			project: 'Change-Notification' with: '0.232.4';
			project: 'OB' with: '0.232.4'.
		spec 
			package: 'Magritte-Model' with: [
				spec
					file:'Magritte-Model-dkh.354';
					postLoadDoIt: #postLoad290Gs.];
			package: 'Magritte-Tests' with: 'Magritte-Tests-dkh.158';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-dkh.305'.].

	! !

!ConfigurationOfMagritte methodsFor: 'versions' stamp: 'DaleHenrichs 2/9/2010 12:13'!
version1213: spec
	<version: '1.2.1.3' imports: #('1.2.1.1-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- pick up Magritte-Model fixes from John McKeon:
  - add defaultMorphicClasses to MAMagnitudeDescription
  - remove class side morphic default
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '2/7/2010 08:44'.
		spec project: 'Seaside2.8a1' with: '2.8.4.2'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Magritte-Model' with: 'Magritte-Model-jmck.368';
			package: 'Magritte-Morph' with: 'Magritte-Morph-jmck.48';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-jmck.315';
			package: 'Magritte-Tests' with: 'Magritte-Tests-lr.159'.].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec description: 'Magritte 1.2.1 not yet ported to GemStone'.
		spec 
			project: 'Core' with: '0.232.4';
			project: 'Change-Notification' with: '0.232.4';
			project: 'OB' with: '0.232.4'.
		spec 
			package: 'Magritte-Model' with: [
				spec 
					file: 'Magritte-Model-dkh.354';
					postLoadDoIt: #postLoad290Gs. ];
			package: 'Magritte-Tests' with: 'Magritte-Tests-dkh.158';
			package: 'Magritte-Seaside' with: 'Magritte-Seaside-dkh.305'.].! !
